@@ -17,6 +17,7 @@ from .exceptions import (
     StorageError,
     UnauthorizedError,
     UnknownError,
+    AlreadyExistsError
 )
 from .models import CamelModel, FileDownloadRef
 from .responses import UJSONResponse
@@ -36,7 +37,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "0.12.1"
+__version__ = "0.13.1"
 
 
 def create_app(
@@ -44,6 +45,7 @@ def create_app(
     disable_gzip: bool = False,
     on_start: Callable[[FastAPI], Awaitable[None]] = None,
     on_stop: Callable[[FastAPI], Awaitable[None]] = None,
+    **kwargs
 ) -> FastAPI:
     settings = get_settings(env_path)
 
@@ -55,6 +57,7 @@ def create_app(
     app = FastAPI(
         title=settings.PROJECT_NAME,
         openapi_url=f"{settings.API_PRE_PATH}/openapi.json",
+        **kwargs
     )
 
     # CORS
