@@ -1,7 +1,8 @@
 import typing
 
 import ujson
-from starlette.responses import UJSONResponse as BaseUJSONResponse
+import orjson
+from starlette.responses import JSONResponse, UJSONResponse as BaseUJSONResponse
 
 
 class UJSONResponse(BaseUJSONResponse):
@@ -26,3 +27,9 @@ class UJSONResponse(BaseUJSONResponse):
         return ujson.dumps(
             content, ensure_ascii=True, escape_forward_slashes=False
         ).encode("utf-8")
+
+class ORJSONResponse(JSONResponse):
+    media_type = "application/json"
+
+    def render(self, content: typing.Any) -> bytes:
+        return orjson.dumps(content)
\ No newline at end of file
