@@ -2,14 +2,11 @@ from io import BytesIO
 from typing import List, Optional, Union
 
 from fastapi import UploadFile
-from minio import Minio, Object
-from minio.error import (
-    BucketAlreadyExists,
-    BucketAlreadyOwnedByYou,
-    NoSuchKey,
-    ResponseError,
-)
-
+from minio import Minio
+from minio.commonconfig import CopySource
+from minio.datatypes import Object
+from minio.deleteobjects import DeleteObject
+from minio.error import MinioException
 from fa_common import StorageError, force_async, get_current_app
 from fa_common import logger as LOG
 from fa_common import sizeof_fmt
@@ -44,11 +41,14 @@ class MinioClient(BaseClient):
     async def make_bucket(self, name: str) -> None:
         try:
             await force_async(self.minio.make_bucket)(name)
-        except BucketAlreadyOwnedByYou:
-            LOG.warning(f"Bucket {name} already owned by app")
-        except BucketAlreadyExists:
-            LOG.warning(f"Bucket {name} already exists")
-        except ResponseError as err:
+        except MinioException as err:
+            if hasattr(err, "code") and err.code == "BucketAlreadyOwnedByYou":
+                LOG.warning(f"Bucket {name} already owned by app")
+                return
+            if hasattr(err, "code") and err.code == "BucketAlreadyExists":
+                LOG.warning(f"Bucket {name} already exists")
+                return
+
             LOG.error(f"Unable to create bucket {name}")
             LOG.error(err)
             raise err
@@ -62,9 +62,7 @@ class MinioClient(BaseClient):
         return f"{bucket_name}/{path}"
 
     @classmethod
-    def object_to_file(
-        cls, obj: Object, bucket_name: str, file_name: str = None
-    ) -> Optional[File]:
+    def object_to_file(cls, obj: Object, bucket_name: str, file_name: str = None) -> Optional[File]:
         is_dir = obj.is_dir
         path = obj.object_name
         path_segments = path.split("/")
@@ -91,9 +89,7 @@ class MinioClient(BaseClient):
         )
 
     async def list_files(self, bucket_name: str, parent_path: str = "") -> List[File]:
-        objects = await force_async(self.minio.list_objects_v2)(
-            bucket_name, prefix=parent_path
-        )
+        objects = await force_async(self.minio.list_objects)(bucket_name, prefix=parent_path)
         files: List[File] = []
         for obj in objects:
             file = self.object_to_file(obj, bucket_name)
@@ -110,9 +106,7 @@ class MinioClient(BaseClient):
     ) -> File:
         try:
             string_io: BytesIO = (
-                BytesIO(string.encode("utf-8"))
-                if isinstance(string, str)
-                else BytesIO(string)
+                BytesIO(string.encode("utf-8")) if isinstance(string, str) else BytesIO(string)
             )
             await force_async(self.minio.put_object)(
                 bucket_name,
@@ -122,7 +116,7 @@ class MinioClient(BaseClient):
                 content_type=content_type,
             )
 
-        except ResponseError as err:
+        except MinioException as err:
             LOG.error(str(err))
             raise StorageError("Something went wrong uploading file {}", file_path)
         obj = await force_async(self.minio.stat_object)(bucket_name, file_path)
@@ -132,7 +126,10 @@ class MinioClient(BaseClient):
         return scidra_file
 
     async def upload_file(
-        self, file: UploadFile, bucket_name: str, parent_path: str = "",
+        self,
+        file: UploadFile,
+        bucket_name: str,
+        parent_path: str = "",
     ) -> File:
 
         if parent_path != "":
@@ -142,14 +139,10 @@ class MinioClient(BaseClient):
                 bucket_name, parent_path + file.filename, file.file.fileno()
             )
 
-        except ResponseError as err:
+        except MinioException as err:
             LOG.error(str(err))
-            raise StorageError(
-                "Something went wrong uploading file {}", parent_path + file.filename
-            )
-        obj = await force_async(self.minio.stat_object)(
-            bucket_name, parent_path + file.filename
-        )
+            raise StorageError("Something went wrong uploading file {}", parent_path + file.filename)
+        obj = await force_async(self.minio.stat_object)(bucket_name, parent_path + file.filename)
         scidra_file = self.object_to_file(obj, bucket_name, parent_path + file.filename)
         if scidra_file is None:
             raise StorageError("A file could not be created from the Minio obj")
@@ -160,6 +153,7 @@ class MinioClient(BaseClient):
         return self.object_to_file(obj_ref, bucket_name)
 
     async def get_file(self, bucket_name: str, file_path: str) -> Optional[BytesIO]:
+        obj = None
         try:
             obj = await force_async(self.minio.get_object)(bucket_name, file_path)
             bytes_stream = BytesIO()
@@ -167,12 +161,16 @@ class MinioClient(BaseClient):
                 bytes_stream.write(d)
 
             return bytes_stream
-        except NoSuchKey:
-            return None
-        except ResponseError as err:
+        except MinioException as err:
+            if hasattr(err, "code") and err.code == "NoSuchKey":
+                return None
             # Likely the file doesn't exist
             LOG.error(str(err))
             raise StorageError("Error getting file {}", file_path)
+        finally:
+            if obj is not None:
+                obj.close()
+                obj.release_conn()
 
     async def file_exists(self, bucket_name: str, file_path: str) -> bool:
         try:
@@ -181,88 +179,63 @@ class MinioClient(BaseClient):
             if stats is None:
                 return False
             return True
-        except NoSuchKey:
-            return False
-        except ResponseError as err:
+        except MinioException as err:
+            if hasattr(err, "code") and err.code == "NoSuchKey":
+                return False
+
             LOG.error(str(err))
             raise StorageError("Error checking if {} exists", file_path)
 
     async def folder_exists(self, bucket_name: str, path: str) -> bool:
-        objects = await force_async(self.minio.list_objects_v2)(
-            bucket_name, prefix=path
-        )
+        objects = await force_async(self.minio.list_objects)(bucket_name, prefix=path)
         for obj in objects:
             if obj is not None:
                 return True
         else:
             return False
 
-    async def delete_file(
-        self, bucket_name: str, file_path: str, recursive: bool = False
-    ) -> None:
+    async def delete_file(self, bucket_name: str, file_path: str, recursive: bool = False) -> None:
         try:
             if recursive:
-                objects = await force_async(self.minio.list_objects_v2)(
-                    bucket_name, prefix=file_path, recursive=True
+                delete_object_list = map(
+                    lambda x: DeleteObject(x.object_name),
+                    self.minio.list_objects(bucket_name, file_path, recursive=True),
                 )
-                obj_list = []
-                for obj in objects:
-                    obj_list.append(obj.object_name)
-                if len(obj_list) > 0:
-                    for del_err in self.minio.remove_objects(bucket_name, obj_list):
-                        LOG.error(
-                            f"Error while deleting objects in bucket {bucket_name}: {del_err}"
-                        )
+                errors = self.minio.remove_objects(bucket_name, delete_object_list)
+                for error in errors:
+                    LOG.error(f"Error occured when deleting file(s) {error}")
             else:
                 await force_async(self.minio.remove_object)(bucket_name, file_path)
-        except ResponseError as err:
+        except MinioException as err:
             LOG.error(err)
-            raise StorageError(
-                f"Somthing went wrong deleting file(s) {bucket_name}/{file_path}"
-            )
+            raise StorageError(f"Somthing went wrong deleting file(s) {bucket_name}/{file_path}")
 
     async def delete_bucket(self, name: str):
         try:
             await self.delete_file(name, "", True)
             return await force_async(self.minio.remove_bucket)(name)
-        except ResponseError as err:
+        except MinioException as err:
             LOG.error(f"Unable to delete bucket {name}")
             LOG.error(err)
             raise err
 
-    async def rename_file(
-        self, bucket_name: str, file_path: str, new_file_path: str
-    ) -> None:
+    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> None:
         try:
             await force_async(self.minio.copy_object)(
-                bucket_name, new_file_path, f"/{bucket_name}/{file_path}"
-            )
-        except ResponseError as err:
-            LOG.error(
-                f"Error renaming {file_path} to {new_file_path} in bucket {bucket_name}: {str(err)}"
-            )
-            raise StorageError(
-                f"Somthing went wrong renaming {file_path} to {new_file_path}"
+                bucket_name, new_file_path, CopySource(bucket_name, file_path)
             )
+        except MinioException as err:
+            LOG.error(f"Error renaming {file_path} to {new_file_path} in bucket {bucket_name}: {str(err)}")
+            raise StorageError(f"Somthing went wrong renaming {file_path} to {new_file_path}")
         await self.delete_file(bucket_name, file_path)
 
-    async def copy_file(
-        self, from_bucket: str, from_path: str, to_bucket: str, to_path: str
-    ) -> None:
+    async def copy_file(self, from_bucket: str, from_path: str, to_bucket: str, to_path: str) -> None:
         try:
-            await force_async(self.minio.copy_object)(
-                to_bucket, to_path, f"/{from_bucket}/{from_path}"
-            )
-        except ResponseError as err:
-            LOG.error(
-                f"Error copying {from_bucket} {from_path} to {to_bucket} {to_path} : {str(err)}"
-            )
+            await force_async(self.minio.copy_object)(to_bucket, to_path, CopySource(from_bucket, from_path))
+        except MinioException as err:
+            LOG.error(f"Error copying {from_bucket} {from_path} to {to_bucket} {to_path} : {str(err)}")
             raise StorageError(f"Somthing went wrong copying {from_path} to {to_path}")
 
-    async def create_temp_file_url(
-        self, bucket: str, path: str, expire_time_hours: int = 3
-    ) -> File:
+    async def create_temp_file_url(self, bucket: str, path: str, expire_time_hours: int = 3) -> File:
         # FIXME make this work
-        raise NotImplementedError(
-            "Minio support for temp downloads currently not working."
-        )
+        raise NotImplementedError("Minio support for temp downloads currently not working.")
